# File Formats

This document the formats and examples of all the input and output
files used in MACS3.

```{toctree}
:maxdepth: 2

callpeakxls.md
SAMBAMBAMPE.md
BED.md
BEDPE.md
FRAG.md
bedGraph.md
narrowPeak.md
broadPeak.md
gappedPeak.md
vcf.md
hmmratacModel.md
